summaryrefslogtreecommitdiff
path: root/src/lib/timer.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2013-12-13 10:06:18 +0000
committerCarl Hetherington <cth@carlh.net>2013-12-13 10:06:18 +0000
commit097a1fb413bbbb89182161d4c1a31daa5419ec96 (patch)
tree87d6ed5b14e7554b26f565380b69528ab3ec10ec /src/lib/timer.h
parentea910e250a0fb3b0ad3ce0cf32dd27b24c17cd1d (diff)
Time -> DCPTime.
Diffstat (limited to 'src/lib/timer.h')
-rw-r--r--src/lib/timer.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/lib/timer.h b/src/lib/timer.h
index 4a5aa12de..8ec392aa6 100644
--- a/src/lib/timer.h
+++ b/src/lib/timer.h
@@ -29,16 +29,16 @@
#include <map>
#include <sys/time.h>
-/** @class PeriodTimer
+/** @class PeriodDCPTimer
* @brief A class to allow timing of a period within the caller.
*
* On destruction, it will output the time since its construction.
*/
-class PeriodTimer
+class PeriodDCPTimer
{
public:
- PeriodTimer (std::string n);
- ~PeriodTimer ();
+ PeriodDCPTimer (std::string n);
+ ~PeriodDCPTimer ();
private:
@@ -48,19 +48,19 @@ private:
struct timeval _start;
};
-/** @class StateTimer
+/** @class StateDCPTimer
* @brief A class to allow measurement of the amount of time a program
* spends in one of a set of states.
*
* Once constructed, the caller can call set_state() whenever
* its state changes. When StateTimer is destroyed, it will
* output (to cout) a summary of the time spent in each state.
*/
-class StateTimer
+class StateDCPTimer
{
public:
- StateTimer (std::string n, std::string s);
- ~StateTimer ();
+ StateDCPTimer (std::string n, std::string s);
+ ~StateDCPTimer ();
void set_state (std::string s);
@@ -48,19 +48,19 @@ private:
*
* Once constructed, the caller can call set_state() whenever
- * its state changes. When StateTimer is destroyed, it will
+ * its state changes. When StateDCPTimer is destroyed, it will
* output (to cout) a summary of the time spent in each state.
*/